Gemeinde Adressverwaltung GUI: Elementverzeichnis

Gemeinde Adressverwaltung GUI

Gemeinde_Modelle.PersonGruppe Elementverzeichnis

Vollständige Aufstellung aller Elemente für Gemeinde_Modelle.PersonGruppe einschließlich aller geerbten Elemente.

__init__(self, id=None, holen=False) (Definiert in Gemeinde_Modelle.PersonGruppe) | Gemeinde_Modelle.PersonGruppe |
__str__(self) (Definiert in Gemeinde_Modelle.PersonGruppe) | Gemeinde_Modelle.PersonGruppe |
keyFeldNavi (Definiert in Gemeinde_Modelle.PersonGruppe) | Gemeinde_Modelle.PersonGruppe | static
R_gruppe (Definiert in Gemeinde_Modelle.PersonGruppe) | Gemeinde_Modelle.PersonGruppe | static
R_person (Definiert in Gemeinde_Modelle.PersonGruppe) | Gemeinde_Modelle.PersonGruppe | static